@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "julia-repl" "1.5.2"
+(define-package "julia-repl" "20250719.1449"
   "A minor mode for a Julia REPL."
   '((emacs "29.1")
     (s     "1.12"))
   :url "https://github.com/tpapp/julia-repl"
-  :commit "0173237a43d9a42f0d69a5405283fabe1ac602a0"
-  :revdesc "0173237a43d9"
+  :commit "681efc14a72ece3390137b01c4ee67f317cd8324"
+  :revdesc "681efc14a72e"
   :keywords '("languages")
   :authors '(("Tamas Papp" . "tkpapp@gmail.com"))
   :maintainers '(("Tamas Papp" . "tkpapp@gmail.com")))
