@@ -3,8 +3,8 @@
 ;; Copyright (C) 2016–2024 Tamas K. Papp
 ;; Author: Tamas Papp <tkpapp@gmail.com>
 ;; Keywords: languages
-;; Package-Version: 1.5.2
-;; Package-Revision: 0173237a43d9
+;; Package-Version: 20250719.1449
+;; Package-Revision: 681efc14a72e
 ;; Package-Requires: ((emacs "29.1")(s "1.12"))
 ;; URL: https://github.com/tpapp/julia-repl
 
@@ -53,7 +53,7 @@
 ;;
 
 (defgroup julia-repl nil
-  "A minor mode for a Julia REPL."
+  "A minor mode for a Julia REPL"
   :group 'julia)
 
 (defcustom julia-repl-inferior-buffer-name-base "julia"
@@ -86,19 +86,16 @@ Note that this affects all buffers using the ‘ansi-term’ map."
   :group 'julia-repl)
 
 (defcustom julia-repl-pop-to-buffer t
-  "When non-nil, pop to `julia-repl'."
+  "When non-nil pop to julia repl"
   :type 'symbol
   :group 'julia-repl)
 
 (defcustom julia-repl-path-rewrite-rules nil
   "A list of rewrite rules applied to paths sent with ‘include’ and similar.
 
-Each rule should be a function that is called with a path, in the given
-order. If the function returns nil, the next one is tried, otherwise
-the result is used as the rewritten path.
+Each rule should be a function that is called with a path, in the given order. If the function returns ‘nil’, the next one is tried, otherwise the result is used as the rewritten path.
 
-This can be used a workaround, usually necessary on non-Unix systems. Eg
-for Cygwin-based Windows, use
+This can be used a workaround, usually necessary on non-Unix systems. Eg for Cygwin-based Windows, use
 
    (setq julia-repl-path-rewrite-rules julia-repl-cygwin-path-rewrite-rules)
 
@@ -112,7 +109,7 @@ in your Emacs init file after loading this package."
   :group 'julia-repl)
 
 (defcustom julia-repl-set-term-escape t
-  "Set the escape char \`C-x globally for term. Useful for switching windows, but users who do not want this globally should set it to nil."
+  "Set the escape char C-x globally for term. Useful for switching windows, but users who do not want this globally should set it to nil."
   :type 'boolean
   :group 'julia-repl)
 
@@ -269,29 +266,14 @@ When PASTE-P, “bracketed paste” mode will be used. When RET-P, terminate wit
       (when ret-p
 	(eat-term-send-string eat-terminal "\^M")))))
 
-;;; compiler output regexps for navigation
-
-(defconst julia-repl--CR-path
-  (rx (+ (not (any space ">" "<" "(" ")" "\t" "\n" "," "'" "\"" ";" ":"))))
-  "A regexp matching paths (in Julia stacktraces).")
-
 (defconst julia-repl--CR-at
-  (rx "@" space
-      (? (group (one-or-more (or (any "._") alnum))) space) ; group 1: module name
-      (group (regexp julia-repl--CR-path)) ; group 2: path
-      ":"
-      (group (+ num))                   ; group 3: line number
-      )
-  "Matches “@ Foo ~/code/Foo/src/Foo.jl:100”. This is what is used in Julia >= 1.6")
-
-(defconst julia-repl--CR-expression-starting
-  (rx "in expression starting at"
-      (+ space)
-      (group (regexp julia-repl--CR-path)) ; group 1: path
-      ":"
-      (group (+ num))                   ; group 2: line
-      )
-  "Matches “in expression starting at ~/code/Foo/src/Foo.jl:100”.")
+   (rx "@" space
+       (? (group (one-or-more (or  (any "._") alnum))) space)    ; group 1: module name
+       (group (+ (not (any space ">" "<" "(" ")" "\t" "\n" "," "'" "\"" ";" ":")))) ; group 2: path
+       ":"
+       (group (+ num))                    ; group 3: line number
+       )
+   "Matches “@ Foo ~/code/Foo/src/Foo.jl:100”. This is what is used in Julia >= 1.6")
 
 (defconst julia-repl--CR-filename
   (rx (one-or-more (not (any " ><()\t\n,'\";:"))))
@@ -410,8 +392,7 @@ a new Julia process is started.")
   "Return an alist suitable for use in `compilation-error-regexp-alist' for recognizing Julia error locations.
 
  Cf `julia-repl-compilation-location-legacy'."
-  (let ((regexp-alist `((,julia-repl--CR-at 2 3)
-                        (,julia-repl--CR-expression-starting 1 2))))
+  (let ((regexp-alist `((,julia-repl--CR-at 2 3))))
     (if julia-repl-compilation-location-legacy
         (cons regexp-alist
               `((,julia-repl--CR-load-error 1 2) (,julia-repl--CR-around 1 2)))
@@ -479,8 +460,7 @@ prevent further attempts."
   (unless (plist-member (cddr executable-record) :basedir)
     (let* ((executable-path (julia-repl--executable-path executable-record))
            (basedir (julia-repl--capture-basedir executable-path)))
-      (when basedir
-        (nconc executable-record `(:basedir ,basedir)))
+      (nconc executable-record `(:basedir ,basedir))
       (unless basedir
         (warn "could not capture basedir for Julia executable %s"
               executable-path)))))
@@ -661,7 +641,7 @@ This is the standard entry point for using this package."
   "Switch to the buffer that was active before last call to `julia-repl'."
   (interactive)
   (when (buffer-live-p julia-repl--script-buffer)
-    (if julia-repl-pop-to-buffer
+    (if julia-repl-pop-to-buffer 
 	(switch-to-buffer-other-window julia-repl--script-buffer)
       (switch-to-buffer julia-repl--script-buffer))))
 
@@ -947,7 +927,7 @@ be added."
 
 \\{julia-repl-mode-map}"
   :init-value nil
-  :lighter " >"
+  :lighter ">"
   :keymap
   `((,(kbd "C-c C-a")    . julia-repl-activate-parent)
     (,(kbd "C-c C-b")    . julia-repl-send-buffer)
